@@ -1,6 +1,6 @@
 # Statistics Menu dialogs
 
-# last modified 2019-12-11 by J. Fox
+# last modified 2022-06-30 by J. Fox
 
 # Variances menu
 
@@ -100,6 +100,7 @@ BartlettTest <- function () {
                           .activeDataSet, ") # variances by group")) 
       doItAndPrint(paste("bartlett.test(", response, " ~ ", 
                          group, ", data=", .activeDataSet, ")", sep = ""))
+      insertRmdSection(paste0(gettextRmdHeader("Bartlett's Test: "), response, " ~ ", group))
     }
     else{
       # command <- paste("with(", .activeDataSet, ", tapply(", response, 
@@ -109,6 +110,7 @@ BartlettTest <- function () {
       doItAndPrint(command)
       doItAndPrint(paste("bartlett.test(", response, " ~ interaction(", 
                          paste(group, collapse=", "), "), data=", .activeDataSet, ")", sep = ""))
+      insertRmdSection(paste0(gettextRmdHeader("Bartlett's Test: "), response, " ~ ", paste(group, collapse="*")))
     }
     tkfocus(CommanderWindow())
   }
